"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: ef9914284afb

from __future__ import annotations
from mistralai.client.types import BaseModel
from mistralai.client.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class AgentsAPIV1AgentsGetVersionRequestTypedDict(TypedDict):
    agent_id: str
    version: str


class AgentsAPIV1AgentsGetVersionRequest(BaseModel):
    agent_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    version: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
