"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: f62d73a27faa

from __future__ import annotations
from mistralai.client.types import BaseModel
from typing_extensions import TypedDict


class AudioURLTypedDict(TypedDict):
    r"""Audio URL.

    Attributes:
    url: The URL of the audio file.
    """

    url: str


class AudioURL(BaseModel):
    r"""Audio URL.

    Attributes:
    url: The URL of the audio file.
    """

    url: str
