"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 41ca596b44f8

from __future__ import annotations
from .connectortoollocale import ConnectorToolLocale, ConnectorToolLocaleTypedDict
from .executionconfig import ExecutionConfig, ExecutionConfigTypedDict
from .resourcevisibility import ResourceVisibility
from datetime import datetime
from mistralai.client.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Any, Dict
from typing_extensions import NotRequired, TypedDict


class ConnectorToolTypedDict(TypedDict):
    id: str
    name: str
    description: str
    execution_config: Nullable[ExecutionConfigTypedDict]
    visibility: ResourceVisibility
    created_at: datetime
    modified_at: datetime
    system_prompt: NotRequired[Nullable[str]]
    locale: NotRequired[Nullable[ConnectorToolLocaleTypedDict]]
    jsonschema: NotRequired[Nullable[Dict[str, Any]]]
    active: NotRequired[Nullable[bool]]


class ConnectorTool(BaseModel):
    id: str

    name: str

    description: str

    execution_config: Nullable[ExecutionConfig]

    visibility: ResourceVisibility

    created_at: datetime

    modified_at: datetime

    system_prompt: OptionalNullable[str] = UNSET

    locale: OptionalNullable[ConnectorToolLocale] = UNSET

    jsonschema: OptionalNullable[Dict[str, Any]] = UNSET

    active: OptionalNullable[bool] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["system_prompt", "locale", "jsonschema", "active"])
        nullable_fields = set(
            ["system_prompt", "locale", "jsonschema", "execution_config", "active"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            is_nullable_and_explicitly_set = (
                k in nullable_fields
                and (self.__pydantic_fields_set__.intersection({n}))  # pylint: disable=no-member
            )

            if val != UNSET_SENTINEL:
                if (
                    val is not None
                    or k not in optional_fields
                    or is_nullable_and_explicitly_set
                ):
                    m[k] = val

        return m
