"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""
# @generated-id: 86c3b54272fd

from __future__ import annotations
from mistralai.client.types import UnrecognizedStr
from typing import Literal, Union


ToolTypes = Union[Literal["function",], UnrecognizedStr]
